PrivAdbAuthorizationCheckResult class abstract

Outcome of an ADB authorization check.

Available extensions
Annotations
  • @freezed

Constructors

PrivAdbAuthorizationCheckResult({required PrivAdbAuthorizationStatus status, @Default.new('') String outputText, @Default.new('') String deviceName, @Default.new('') String publicKeyFingerprint, String? failureMessage})
const
factory
PrivAdbAuthorizationCheckResult.fromMap(Map map)
factory

Properties

copyWith → $PrivAdbAuthorizationCheckResultCopyWith<PrivAdbAuthorizationCheckResult>
Create a copy of PrivAdbAuthorizationCheckResult with the given fields replaced by the non-null parameter values.
no setterinherited
deviceName String
no setterinherited
failureMessage String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isAuthorized bool
Whether the ADB key is authorized on this endpoint.
no setter
outputText String
no setterinherited
publicKeyFingerprint String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PrivAdbAuthorizationStatus
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PrivAdbAuthorizationCheckResult value)) → TResult

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PrivAdbAuthorizationCheckResult value)?) → TResult?

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PrivAdbAuthorizationCheckResult value)?, {required TResult orElse()}) → TResult

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PrivAdbAuthorizationStatus status, String outputText, String deviceName, String publicKeyFingerprint, String? failureMessage)?, {required TResult orElse()}) → TResult

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PrivAdbAuthorizationStatus status, String outputText, String deviceName, String publicKeyFingerprint, String? failureMessage)) → TResult

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PrivAdbAuthorizationStatus status, String outputText, String deviceName, String publicKeyFingerprint, String? failureMessage)?) → TResult?

Available on PrivAdbAuthorizationCheckResult, provided by the PrivAdbAuthorizationCheckResultPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited