PrivAdbConnectionOptions class abstract

Connection options for an ADB start.

Mirrors priv.kit.core.adb.PrivilegeAdbConnectionOptions.

Available extensions
Annotations
  • @freezed

Constructors

PrivAdbConnectionOptions({int? port, @Default.new(PrivAdbWirelessDebuggingControl.ifAvailable) PrivAdbWirelessDebuggingControl wirelessDebuggingControl, @Default.new(true) bool disableWirelessDebuggingAfterUse, @Default.new(15000) int portDiscoveryTimeoutMillis, @Default.new(5) int connectRetryCount, @Default.new(1000) int connectRetryDelayMillis})
const
factory

Properties

connectRetryCount int
no setterinherited
connectRetryDelayMillis int
no setterinherited
copyWith → $PrivAdbConnectionOptionsCopyWith<PrivAdbConnectionOptions>
Create a copy of PrivAdbConnectionOptions with the given fields replaced by the non-null parameter values.
no setterinherited
disableWirelessDebuggingAfterUse bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
port int?
ADB connect port. null discovers the Wireless Debugging connect port.
no setterinherited
portDiscoveryTimeoutMillis int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wirelessDebuggingControl PrivAdbWirelessDebuggingControl
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PrivAdbConnectionOptions value)) → TResult

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PrivAdbConnectionOptions value)?) → TResult?

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PrivAdbConnectionOptions value)?, {required TResult orElse()}) → TResult

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? port, PrivAdbWirelessDebuggingControl wirelessDebuggingControl, bool disableWirelessDebuggingAfterUse, int portDiscoveryTimeoutMillis, int connectRetryCount, int connectRetryDelayMillis)?, {required TResult orElse()}) → TResult

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Encodes the options for the Android side.
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? port, PrivAdbWirelessDebuggingControl wirelessDebuggingControl, bool disableWirelessDebuggingAfterUse, int portDiscoveryTimeoutMillis, int connectRetryCount, int connectRetryDelayMillis)) → TResult

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? port, PrivAdbWirelessDebuggingControl wirelessDebuggingControl, bool disableWirelessDebuggingAfterUse, int portDiscoveryTimeoutMillis, int connectRetryCount, int connectRetryDelayMillis)?) → TResult?

Available on PrivAdbConnectionOptions, provided by the PrivAdbConnectionOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited