PrivAdbPairingCheckResult class abstract

Outcome of a pairing-state check.

Available extensions
Annotations
  • @freezed

Constructors

PrivAdbPairingCheckResult({int? port, @Default.new(false) bool paired, @Default.new('') String outputText, @Default.new('') String deviceName, @Default.new('') String publicKeyFingerprint, required PrivAdbPairingCheckStatus status, String? failureMessage})
const
factory
PrivAdbPairingCheckResult.fromMap(Map map)
factory

Properties

copyWith → $PrivAdbPairingCheckResultCopyWith<PrivAdbPairingCheckResult>
Create a copy of PrivAdbPairingCheckResult with the given fields replaced by the non-null parameter values.
no setterinherited
deviceName String
no setterinherited
failureMessage String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
outputText String
no setterinherited
paired bool
Whether the app's saved ADB key has been authorized on the device.
no setterinherited
port int?
no setterinherited
publicKeyFingerprint String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PrivAdbPairingCheckStatus
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PrivAdbPairingCheckResult value)) → TResult

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PrivAdbPairingCheckResult value)?) → TResult?

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PrivAdbPairingCheckResult value)?, {required TResult orElse()}) → TResult

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? port, bool paired, String outputText, String deviceName, String publicKeyFingerprint, PrivAdbPairingCheckStatus status, String? failureMessage)?, {required TResult orElse()}) → TResult

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? port, bool paired, String outputText, String deviceName, String publicKeyFingerprint, PrivAdbPairingCheckStatus status, String? failureMessage)) → TResult

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? port, bool paired, String outputText, String deviceName, String publicKeyFingerprint, PrivAdbPairingCheckStatus status, String? failureMessage)?) → TResult?

Available on PrivAdbPairingCheckResult, provided by the PrivAdbPairingCheckResultPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited