adbGetActiveTcpPort method
The static ADB port adbd is currently listening on, if any.
Implementation
Future<int?> adbGetActiveTcpPort({String? adbDeviceName}) {
throw UnimplementedError('adbGetActiveTcpPort() has not been implemented.');
}
The static ADB port adbd is currently listening on, if any.
Future<int?> adbGetActiveTcpPort({String? adbDeviceName}) {
throw UnimplementedError('adbGetActiveTcpPort() has not been implemented.');
}