shutdownServer method
Shuts the connected server down and clears the local connection.
Implementation
Future<void> shutdownServer() {
throw UnimplementedError('shutdownServer() has not been implemented.');
}
Shuts the connected server down and clears the local connection.
Future<void> shutdownServer() {
throw UnimplementedError('shutdownServer() has not been implemented.');
}