startCommand method

Future<void> startCommand(
  1. String commandId,
  2. PrivCommand command, {
  3. int? timeoutMillis,
})

Starts command for streaming consumption and keeps it under commandId.

The process is cancelled when the stream subscription is cancelled or when cancelCommand is called.

Implementation

Future<void> startCommand(
  String commandId,
  PrivCommand command, {
  int? timeoutMillis,
}) {
  throw UnimplementedError('startCommand() has not been implemented.');
}